API Documentation — FRED 1.0 documentation

# API Documentation

All API calls map the raw REST api as closely as possible, including the distinction between required and optional arguments to the calls. This means that the code makes distinction between positional and keyword arguments; we, however, recommend that people use keyword arguments for all calls for consistency and safety.

## Fred

class `fred.` `Fred`(api_key='beaa9d5a890451a1e4a6f0ccad1c3321', response_type='xml')

  Fred client. Provides a straightforward mapping from Python to FRED REST endpoints. The instance has attributes `cateogry`, `release`, `series`, `tag` and `source` that provide access to instances of `fred.clients.categories.CategoriesClient`, `fred.clients.releases.ReleasesClient`, `fred.clients.eseries.ESeriesClient`, `fred.clients.tags.TagsClient` and `fred.clients.sources.SourcesClient` respectively. This is the preferred (and only supported) way to get access to those classes and their methods.

  Parameters: | api_key (str) – 32 character alpha-numeric lowercase string. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

## Categories

class `fred.clients.categories.` `CategoriesClient`(client, api_key, url_root, response_type)

  Class for working with FRED categories

  `children`(*args, **kwargs)

    Function to request a particular category’s children https://research.stlouisfed.org/docs/api/fred/category_children.html

    Parameters: | category_id (int) – The id for a category. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `details`(*args, **kwargs)

    Function to request a particular category’s high-level details https://research.stlouisfed.org/docs/api/fred/category.html

    Parameters: | category_id (int) – The id for a category. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required.

  `related`(*args, **kwargs)

    Function to request a particular category’s related categories. Related categories are A related category is a one-way relation between 2 categories that is not part of a parent-child category hierarchy. Most categories do not have related categories. https://research.stlouisfed.org/docs/api/fred/category_related.html

    Parameters: | category_id (int) – The id for a category. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `related_tags`(*args, **kwargs)

    Function to request FRED related tags for a particular category. FRED tags are attributes assigned to series. Series are assigned tags and categories. Indirectly through series, it is possible to get the tags for a category. No tags exist for a category that does not have series. https://research.stlouisfed.org/docs/api/fred/category_tags.html

    Parameters: | category_id (int) – The id for a category. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. tag_names (str) – Tag names that series match. Required. Separate with semicolon as in “income;bea” realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_id’, ‘title’, ‘units’, ‘frequency’, ‘seasonal_adjustment’, ‘realtime_start’, ‘realtime_end’, ‘last_updated’, ‘observation_start’, ‘observation_end’, ‘popularity’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ exclude_tag_names (str) – Tag names to exclude. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ search_text (str) – The words to find matching tags with. For example ‘mortgage rates’

  `series`(*args, **kwargs)

    Function to request a particular category’s data series https://research.stlouisfed.org/docs/api/fred/category_series.html

    Parameters: | category_id (int) – The id for a category. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_id’, ‘title’, ‘units’, ‘frequency’, ‘seasonal_adjustment’, ‘realtime_start’, ‘realtime_end’, ‘last_updated’, ‘observation_start’, ‘observation_end’, ‘popularity’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ filter_variable (str) – The attribute to filter results by. Options are ‘frequency’, ‘units’,’seasonal_adjustment’ filter_value (str) – The value of the filter_variable attribute to filter results by. tag_names (str) – Tag names used to match series. Separate with semicolon as in “income;bea” exclude_tag_names (str) – Tag names used to exclude series. Separate with semicolon as in “income;bea”

  `tags`(*args, **kwargs)

    Function to request a particular category’s FRED tags. FRED tags are attributes assigned to series. Series are assigned tags and categories. Indirectly through series, it is possible to get the tags for a category. No tags exist for a category that does not have series. https://research.stlouisfed.org/docs/api/fred/category_tags.html

    Parameters: | category_id (int) – The id for a category. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_id’, ‘title’, ‘units’, ‘frequency’, ‘seasonal_adjustment’, ‘realtime_start’, ‘realtime_end’, ‘last_updated’, ‘observation_start’, ‘observation_end’, ‘popularity’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ tag_names (str) – Tag names to only include in the response. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ search_text (str) – The words to find matching tags with. For example ‘mortgage rates’

## Releases

class `fred.clients.releases.` `ReleasesClient`(client, api_key, url_root, response_type)

  Class for working with FRED releases

  `all_dates`(*args, **kwargs)

    Function to request release dates for all releases of economic data. https://research.stlouisfed.org/docs/api/fred/releases_dates.html

    Parameters: | response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘release_date’, ‘release_id’, ‘release_name’. sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ include_release_dates_with_no_data (str) – Determines whether release dates with no data available are returned. Options are ‘true’, ‘false’

  `all_releases`(*args, **kwargs)

    Function to request all releases of economic data. https://research.stlouisfed.org/docs/api/fred/releases.html

    Parameters: | response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘release_id’, ‘name’, ‘press_release’, ‘realtime_start’, ‘realtime_end’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’

  `dates`(*args, **kwargs)

    Function to request release dates for a particular release of economic data. Note that release dates are published by data sources and do not necessarily represent when data will be available on the FRED or ALFRED websites. https://research.stlouisfed.org/docs/api/fred/release_dates.html

    Parameters: | release_id (int) – The id for a release. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 sort_order (str) – Sort results is ascending or descending release date order. Options are ‘asc’,’desc’ include_release_dates_with_no_data (str) – Determines whether release dates with no data available are returned. Options are ‘true’, ‘false’

  `details`(*args, **kwargs)

    Function to request the high-level details for a particular release of economic data.. https://research.stlouisfed.org/docs/api/fred/release.html

    Parameters: | release_id (int) – The id for a release. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `related_tags`(*args, **kwargs)

    Function to request FRED related tags for a particular release. FRED tags are attributes assigned to series. Series are assigned tags and releases. Indirectly through series, it is possible to get the tags for a category. No tags exist for a release that does not have series. https://research.stlouisfed.org/docs/api/fred/release_related_tags.html

    Parameters: | release_id (int) – The id for a release. Required. tag_names (str) – Tag names that series match. Separate with semicolon as in “income;bea”. Required response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ exclude_tag_names (str) – Tag names to exclude. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ search_text (str) – The words to find matching tags with. For example ‘mortgage rates’

  `series`(*args, **kwargs)

    Function to request the series on a release of economic data. https://research.stlouisfed.org/docs/api/fred/release_series.html

    Parameters: | release_id (int) – The id for a release. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_id’, ‘title’, ‘units’, ‘frequency’, ‘seasonal_adjustment’, ‘realtime_start’, ‘realtime_end’, ‘last_updated’, ‘observation_start’, ‘observation_end’, ‘popularity’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ filter_variable (str) – The attribute to filter results by. Options are ‘frequency’, ‘units’,’seasonal_adjustment’ filter_value (str) – The value of the filter_variable attribute to filter results by. tag_names (str) – Tag names used to match series. Separate with semicolon as in “income;bea” exclude_tag_names (str) – Tag names used to exclude series. Separate with semicolon as in “income;bea”

  `sources`(*args, **kwargs)

    Function to request the sources for a particular release of economic data. https://research.stlouisfed.org/docs/api/fred/release.html

    Parameters: | release_id (int) – The id for a release. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `tags`(*args, **kwargs)

    Function to request FRED tags for a particular release. FRED tags are attributes assigned to series. Series are assigned tags and releases. Indirectly through series, it is possible to get the tags for a category. No tags exist for a release that does not have series. https://research.stlouisfed.org/docs/api/fred/release_tags.html

    Parameters: | release_id (int) – The id for a release. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ tag_names (str) – Tag names that series match. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ search_text (str) – The words to find matching tags with. For example ‘mortgage rates’

## Series

class `fred.clients.eseries.` `ESeriesClient`(client, api_key, url_root, response_type)

  Class for working with FRED series

  `categories`(*args, **kwargs)

    Function to request the categories for an economic data series. https://research.stlouisfed.org/docs/api/fred/release.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `details`(*args, **kwargs)

    Function to request a series of economic data. https://research.stlouisfed.org/docs/api/fred/release.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `observations`(*args, **kwargs)

    Function to request the observations or data values for an economic data series. https://research.stlouisfed.org/docs/api/fred/series_observations.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 100000 offset (int) – Data offset. Options >=0 sort_order (str) – Sort results is ascending or descending observation_date order. Options are ‘asc’,’desc’ observation_start (str) – The start of the observation period. Format “YYYY-MM-DD” observation_end (str) – The end of the observation period. Format “YYYY-MM-DD” units (str) – A key that indicates a data value transformation. Options are ‘lin’, ‘chg’, ‘ch1’, ‘pch’, ‘pc1’, ‘pca’, ‘cch’, ‘cca’, ‘log’ frequency (str) – Indicates a lower frequency to aggregate values. Options are ‘d’, ‘w’, ‘bw’, ‘m’, ‘q’, ‘sa’, ‘a’, ‘wef’, ‘weth’, ‘wew’, ‘wetu’, ‘wem’, ‘wesu’, ‘wesa’, ‘bwew’, ‘bwem’ aggregation_method (str) – Indicates the aggregation method used for frequency aggregation. Options are ‘avg’, ‘sum’, ‘eop’ output_type (int) – Output type. Options are 1, 2, 3, 4 vintage_dates (str) – Date(s) in history. Format “YYYY-MM-DD”. Example for multiple dates “2000-01-01,2005-02-24,...”

  `release`(*args, **kwargs)

    Function to request the release for an economic data series. https://research.stlouisfed.org/docs/api/fred/series_release.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `search`(*args, **kwargs)

    Function to request economic data series that match search text. https://research.stlouisfed.org/docs/api/fred/series_search.html

    Parameters: | search_text (str) – The words to match against economic data series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. search_type (str) – Determines the type of search to perform. Options are ‘full_text’,’series_id’ realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘search_rank’, ‘series_id’, ‘title’, ‘units’, ‘frequency’, ‘seasonal_adjustment’, ‘realtime_start’, ‘realtime_end’, ‘last_updated’, ‘observation_start’, ‘observation_end’, ‘popularity’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ filter_variable (str) – The attribute to filter results by. Options are ‘frequency’, ‘units’,’seasonal_adjustment’ filter_value (str) – The value of the filter_variable attribute to filter results by. tag_names (str) – Tag names used to match series. Separate with semicolon as in “income;bea” exclude_tag_names (str) – Tag names used to exclude series. Separate with semicolon as in “income;bea”

  `search_related_tags`(*args, **kwargs)

    Function to request the related FRED tags for one or more FRED tags matching a series search. https://research.stlouisfed.org/docs/api/fred/series_search_related_tags.html

    Parameters: | series_search_text (str) – The words to match against economic data series. Required. tag_names (str) – Tag names that series match. Separate with semicolon as in “income;bea”. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ tag_search_text (str) – The words to find matching tags with. exclude_tag_names (str) – Tag names to exclude. Separate with semicolon as in “income;bea”

  `search_tags`(*args, **kwargs)

    Function to request the FRED tags for a series search. https://research.stlouisfed.org/docs/api/fred/series_search_tags.html

    Parameters: | series_search_text (str) – The words to match against economic data series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ tag_names (str) – Tag names that series match. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ tag_search_text (str) – The words to find matching tags with.

  `tags`(*args, **kwargs)

    Function to request FRED tags for a particular series. FRED tags are attributes assigned to series. https://research.stlouisfed.org/docs/api/fred/series_tags.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’

  `updates`(*args, **kwargs)

    Function to request economic data series sorted by when observations were updated on the FRED server (attribute last_updated). Results are limited to series updated within the last two weeks. https://research.stlouisfed.org/docs/api/fred/series_updates.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 filter_value (str) – Limit results by geographic type of economic data series. Options are ‘macro’, ‘regional’, and ‘all’

  `vintage_dates`(*args, **kwargs)

    Function to request the dates in history when a series’ data values were revised or new data values were released. Vintage dates are the release dates for a series excluding release dates when the data for the series did not change. https://research.stlouisfed.org/docs/api/fred/series_vintagedates.html

    Parameters: | series_id (int) – The id for a series. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 sort_order (str) – Sort results by vintage_date. Options are ‘asc’,’desc’

## Sources

class `fred.clients.sources.` `SourcesClient`(client, api_key, url_root, response_type)

  Class for working with FRED sources

  `details`(*args, **kwargs)

    Function to request a particular source of economic data. https://research.stlouisfed.org/docs/api/fred/source.html

    Parameters: | source_id (int) – The id for a source. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD”

  `releases`(*args, **kwargs)

    Function to request all releases of economic data. https://research.stlouisfed.org/docs/api/fred/releases.html

    Parameters: | source_id (int) – The id for a source. Required. response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘source_id’, ‘name’, ‘realtime_start’, ‘realtime_end’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’

  `sources`(*args, **kwargs)

    Function to request all sources of economic data. https://research.stlouisfed.org/docs/api/fred/sources.html

    Parameters: | response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘source_id’, ‘name’, ‘realtime_start’, ‘realtime_end’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’

## Tags

class `fred.clients.tags.` `TagsClient`(client, api_key, url_root, response_type)

  Class for working with FRED tags

  `related_tags`(*args, **kwargs)

    Function to request FRED related tags. FRED tags are attributes assigned to series. https://research.stlouisfed.org/docs/api/fred/related_tags.html

    Parameters: | tag_names (str) – Tag names that series match. Required. Separate with semicolon as in “income;bea” response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ exclude_tag_names (str) – Tag names to exclude. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ search_text (str) – The words to find matching tags with. For example ‘mortgage rates’

  `series`(*args, **kwargs)

    Function to request series matching all tags in the tag_names parameter. https://research.stlouisfed.org/docs/api/fred/category_series.html

    Parameters: | tag_names (str) – Tag names that series match. Required. Separate with semicolon as in “income;bea” response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_id’, ‘title’, ‘units’, ‘frequency’, ‘seasonal_adjustment’, ‘realtime_start’, ‘realtime_end’, ‘last_updated’, ‘observation_start’, ‘observation_end’, ‘popularity’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ exclude_tag_names (str) – Tag names used to exclude series. Separate with semicolon as in “income;bea”

  `tags`(*args, **kwargs)

    Function to request FRED tags. FRED tags are attributes assigned to series. https://research.stlouisfed.org/docs/api/fred/tags.html

    Parameters: | response_type (str) – File extension of response. Options are ‘xml’, ‘json’, ‘dict’,’df’,’numpy’,’csv’,’tab,’pipe’. Required. realtime_start (str) – The start of the real-time period. Format “YYYY-MM-DD” realtime_end (str) – The end of the real-time period. Format “YYYY-MM-DD” limit (int) – The maximum number of results to return. Options 1 to 1000 offset (int) – Data offset. Options >=0 order_by (str) – Order results by values of the specified attribute. Options are ‘series_count’, ‘popularity’, ‘created’, ‘name’, ‘group_id’ sort_order (str) – Sort results for attribute values specified by order_by. Options are ‘asc’,’desc’ tag_names (str) – Tag names to only include in the response. Separate with semicolon as in “income;bea” tag_group_id (str) – Tag ID to filter tags by. Options are ‘freq’, ‘gen’, ‘geo’, ‘geot’, ‘rls’, ‘seas’, ‘src’ search_text (str) – The words to find matching tags with. For example ‘mortgage rates’